@@ -8,6 +8,9 @@ package GPLVote::SignDoc::Client;
 # $Id: Client.pm,v 0.1 2014/12/17 00:10:00 Andrey Velikoredchanin $
 
 use Crypt::OpenSSL::RSA;
+use Crypt::OpenSSL::AES;
+use Crypt::CBC;
+use Bytes::Random::Secure qw(random_bytes);
 use MIME::Base64;
 use LWP::UserAgent;
 use Digest::SHA qw(sha256_base64);
@@ -27,7 +30,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 %EXPORT_TAGS = (DEFAULT => [qw(&user_sign_is_valid &calc_pub_key_id &encrypt &send_doc &get_docs &split_base64)]);
 
 BEGIN {
-  $VERSION = '0.2';
+  $VERSION = '0.3';
 }
 
 =head1 NAME
@@ -36,7 +39,6 @@ GPLVote::SignDoc::Client -  module for helping create GPLVote SignDoc client sof
 
 =head1 SYNOPSIS
 
- # In finction-oriented style.
  use GPLVote::SignDoc::Client;
 
  if (user_sign_is_valid($public_key, $sign, $data)) {
@@ -199,16 +201,31 @@ sub calc_pub_key_id {
 sub encrypt {
   my ($b64_pub_key, $data) = @_;
 
+  my $b64_open_key = "-----BEGIN PUBLIC KEY-----\n".split_base64($b64_pub_key)."\n-----END PUBLIC KEY-----";
+
+  my $rsa = Crypt::OpenSSL::RSA->new_public_key($b64_open_key);
+  $rsa->use_pkcs1_padding();
   if (length($data) <= 256) {
-    my $b64_open_key = "-----BEGIN PUBLIC KEY-----\n".split_base64($b64_pub_key)."\n-----END PUBLIC KEY-----";
-
-    my $rsa = Crypt::OpenSSL::RSA->new_public_key($b64_open_key);
-    $rsa->use_pkcs1_padding();
-
     return(encode_base64($rsa->encrypt($data), ''));
   } else {
     # TODO: реализовать блочное шифрование большого файла
+    # Первые 256 байт - зашифрованный 256-битный AES ключ
+    # Дальше - данные зашифрованные AES с помощью этого ключа
+    my $enc_data = '';
+    
+    my $aes_key = random_bytes(32);
+    $enc_data .= $rsa->encrypt($aes_key);
 
+    my $aes_cbc = Crypt::CBC->new( -key => $aes_key,
+                                    -literal_key => 1,
+                                    -keysize => 32,
+                                    -cipher => "Crypt::OpenSSL::AES",
+                                    -iv => '7350264181172691',
+                                    -header => 'none' );
+    
+    $enc_data .= $aes_cbc->encrypt($data);
+
+    return(encode_base64($enc_data, ''));
   };
 };
 
